ProviderEvent

Enum ProviderEvent 

#[non_exhaustive]
pub enum ProviderEvent {
Show 14 variants Start { partial: Arc<AssistantMessage>, }, TextStart { content_index: usize, partial: Arc<AssistantMessage>, }, TextDelta { content_index: usize, delta: String, partial: Arc<AssistantMessage>, }, TextEnd { content_index: usize, content: String, partial: Arc<AssistantMessage>, }, ThinkingStart { content_index: usize, partial: Arc<AssistantMessage>, }, ThinkingDelta { content_index: usize, delta: String, partial: Arc<AssistantMessage>, }, ThinkingEnd { content_index: usize, content: String, partial: Arc<AssistantMessage>, }, ToolCallStart { content_index: usize, tool_call_id: Option<String>, tool_name: Option<String>, partial: Arc<AssistantMessage>, }, ToolCallDelta { content_index: usize, delta: String, partial: Arc<AssistantMessage>, }, ToolCallEnd { content_index: usize, tool_call: ToolCall, partial: Arc<AssistantMessage>, }, Done { reason: StopReason, message: AssistantMessage, }, Error { reason: StopReason, error: AssistantMessage, }, FallbackStart { from_model: String, to_model: String, reason: FallbackReason, }, FallbackExhausted { models_tried: Vec<String>, final_error: String, },
}
Provider trait, streaming options, and provider registry. Streaming events emitted by providers

Note: We use crate::AssistantMessage directly to avoid type alias conflicts

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Start

Stream started with partial assistant message.

Fields

partial: Arc<AssistantMessage>

Partial assistant message state.



TextStart

Text content block started.

Fields

content_index: usize

Index of the content block in the message.

partial: Arc<AssistantMessage>

Partial assistant message state.



TextDelta

Incremental text delta received.

Fields

content_index: usize

Index of the content block in the message.

delta: String

The text delta to append.

partial: Arc<AssistantMessage>

Partial assistant message state.



TextEnd

Text content block finished.

Fields

content_index: usize

Index of the content block in the message.

content: String

The complete text content.

partial: Arc<AssistantMessage>

Partial assistant message state.



ThinkingStart

Thinking content block started.

Fields

content_index: usize

Index of the content block in the message.

partial: Arc<AssistantMessage>

Partial assistant message state.



ThinkingDelta

Incremental thinking delta received.

Fields

content_index: usize

Index of the content block in the message.

delta: String

The thinking text delta to append.

partial: Arc<AssistantMessage>

Partial assistant message state.



ThinkingEnd

Thinking content block finished.

Fields

content_index: usize

Index of the content block in the message.

content: String

The complete thinking content.

partial: Arc<AssistantMessage>

Partial assistant message state.



ToolCallStart

Tool call block started.

Fields

content_index: usize

Index of the content block in the message.

tool_call_id: Option<String>

The tool call ID from the provider, if available at start time. Providers that only surface the ID later (in deltas/end) leave this None.

tool_name: Option<String>

The tool name, if available at start time.

partial: Arc<AssistantMessage>

Partial assistant message state.



ToolCallDelta

Tool call delta received (partial JSON arguments).

Fields

content_index: usize

Index of the content block in the message.

delta: String

The delta string to append to tool arguments.

partial: Arc<AssistantMessage>

Partial assistant message state.



ToolCallEnd

Tool call block finished.

Fields

content_index: usize

Index of the content block in the message.

tool_call: ToolCall

The complete tool call with resolved arguments.

partial: Arc<AssistantMessage>

Partial assistant message state.



Done

Stream completed successfully.

Fields

reason: StopReason

Why the model stopped generating.

message: AssistantMessage

The final assistant message.



Error

Stream ended with an error.

Fields

reason: StopReason

The stop reason at time of error.

error: AssistantMessage

Error details in assistant message form.



FallbackStart

Model fallback occurred — primary model replaced by fallback.

Emitted by MultiProvider when it switches from one model to another in the candidate list due to errors, circuit breaker opens, etc.

Fields

from_model: String

Model that was being attempted.

to_model: String

Model that will be used instead.

reason: FallbackReason

Reason for the fallback.



FallbackExhausted

Fallback chain exhausted — all models failed.

Emitted by MultiProvider when all candidates in the fallback chain have been exhausted without success.

Fields

models_tried: Vec<String>

All models that were tried, in order.

final_error: String

Final error from the last model.

Implementations

Source

impl ProviderEvent

pub fn partial(&self) -> Option<&AssistantMessage>

Extract the partial assistant message if present

pub fn is_done(&self) -> bool

Check if this is a done event

pub fn is_error(&self) -> bool

Check if this is an error event

pub fn is_fallback(&self) -> bool

Check if this is a fallback event

pub fn is_fallback_exhausted(&self) -> bool

Check if this is a fallback exhausted event