pub struct TransformOptions {
pub strip_thinking: bool,
pub convert_tools: bool,
pub convert_images: bool,
pub merge_text: bool,
}Expand description
Message transformation between provider formats. Options that control how messages are transformed between providers.
Fields
strip_thinking: boolStrip thinking blocks entirely instead of converting them to text.
convert_tools: boolConvert tool calls / tool results (when false, tool calls are dropped).
convert_images: boolConvert image blocks (when false, images are dropped).
merge_text: boolMerge adjacent text blocks produced by the transformation.